@@ -9,7 +9,7 @@
 #define AudioOpenAL_h
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #ifdef AUDIO_OPENAL
