@@ -14,7 +14,7 @@
 extern "C" {
 #endif
 
-#include <SDL/SDL_mixer.h>
+#include <SDL_mixer.h>
 
 #include "Audio.h"
 
