@@ -7,7 +7,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #include "EnemyAmmo.h"
@@ -18,7 +18,7 @@
 
 #include "compatibility.h"
 
-#ifdef HAVE_APPLE_OPENGL_FRAMEWORK
+#if defined(HAVE_APPLE_OPENGL_FRAMEWORK) || defined(HAVE_OPENGL_GL_H)
 #include <OpenGL/gl.h>
 #else
 #include <GL/gl.h>
