@@ -13,9 +13,15 @@
 
 #if IMAGE_SDL
 
-#include <SDL/SDL.h>
-#include <SDL/SDL_opengl.h>
-#include <SDL/SDL_image.h>
+#include <SDL.h>
+#include <SDL_opengl.h>
+#include <SDL_image.h>
+
+#if defined(HAVE_APPLE_OPENGL_FRAMEWORK) || defined(HAVE_OPENGL_GLU_H)
+#include <OpenGL/glu.h>
+#else
+#include <GL/glu.h>
+#endif
 
 #elif IMAGE_GLPNG
 
