@@ -7,7 +7,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #include "gettext.h"
@@ -20,7 +20,11 @@
 #include <cstdlib>
 #include <unistd.h>
 
+#ifdef HAVE_GLUT_GLUT_H
+#include <GLUT/glut.h>
+#else
 #include <GL/glut.h>
+#endif
 
 #include "Config.h"
 #include "HiScore.h"
@@ -123,7 +127,6 @@ void MainGLUT::grabMouse(bool status, bool warpmouse)
 bool MainGLUT::setVideoMode()
 {
 	Config	*config = Config::instance();
-	config->setScreenSize(config->screenSize()); //  set screenW & screenH for new screenSize
 	glutReshapeWindow(config->screenW(), config->screenH());
 	config->setFullScreen(false);
 	// GLUT doesn't have a way to return resize errors
