@@ -3,7 +3,7 @@
  *
  * "Chromium B.S.U." is free software; you can redistribute 
  * it and/or use it and/or modify it under the terms of the 
- * "Artistic License" 
+ * "Clarified Artistic License"
  */
 #ifndef MainToolkit_h
 #define MainToolkit_h
@@ -23,7 +23,7 @@ public:
 	virtual bool run() = 0;
 	virtual bool checkErrors() = 0;
 	
-	virtual void setVideoMode() = 0;
+	virtual bool setVideoMode() = 0;
 	
 	virtual void grabMouse(bool,bool=true) = 0;
 };
