@@ -9,12 +9,12 @@
 #define MenuGL_h
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #include "compatibility.h"
 
-#ifdef HAVE_APPLE_OPENGL_FRAMEWORK
+#if defined(HAVE_APPLE_OPENGL_FRAMEWORK) || defined(HAVE_OPENGL_GL_H)
 #include <OpenGL/gl.h>
 #else
 #include <GL/gl.h>
@@ -30,7 +30,7 @@ class MenuGL
 public:
 	enum MenuSelection {	NewGame, GameLevel, SkillLevel, Graphics, 
 							FullScreen, ScreenSize, Sound, 
-							Music, MouseSpeed, Quit, 
+							Music, MovementSpeed, Quit,
 							NumSelections };
 	
 	MenuGL();
