@@ -9,7 +9,7 @@
 #define define_h
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 //#define SRAND (2.0*(0.5-(rand()/(double)RAND_MAX)))
@@ -22,8 +22,8 @@
 #define AMMO_REFILL 150
 #define HERO_Z	25.0f
 
-#define MIN_SCREEN_SIZE 0 // 4 == 512x384
-#define MAX_SCREEN_SIZE 4 // 4 == 1280x960
+#define MIN_SCREEN_SIZE 0 // 512x384
+#define MAX_SCREEN_SIZE 4 // 1280x960
 
 #define NUM_ENEMY_AMMO_TYPES 5
 #define NUM_HERO_AMMO_TYPES 3
@@ -46,18 +46,4 @@
 
 #define HI_SCORE_HIST 5
 
-#define MAX_BUFF 256
-
-#ifdef PKGBINDIR
-#define CHROMIUM_EXEC PKGBINDIR"/"PACKAGE
-#else 
-#define CHROMIUM_EXEC "./"PACKAGE
-#endif //PKGBINDIR
-
-#ifdef PKGDATADIR
-#define CHROMIUM_DATA_DIR PKGDATADIR"/data"
-#else
-#define CHROMIUM_DATA_DIR "../data"
-#endif //PKGDATADIR
-
 #endif // define_h
